@@ -5,4 +5,4 @@ def open(q, ex):
     """
     Например open(2, 10) открывает q2.10
     """
-    return IFrame(f'./{q}-{ex}.pdf', width=600, height=300)
+    return IFrame(f'2-1.pdf', width=600, height=300)
